@@ -1,4 +1,4 @@
-use rrw::{RestConfig, RestRequest};
+use rrw::{Error, RestConfig, RestRequest, StandardRestError};
 use rrw_macro::rest;
 use serde::{Deserialize, Serialize};
 
@@ -15,7 +15,10 @@ struct Location {
 
 #[rest]
 impl Bahn {
-    async fn location(&self, location: &LocationQuery) -> Result<Vec<Location>, reqwest::Error> {
+    async fn location(
+        &self,
+        location: &LocationQuery,
+    ) -> Result<Vec<Location>, Error<StandardRestError>> {
         RestRequest::<&LocationQuery, ()>::get("/locations").query(location)
     }
 }
