@@ -1,5 +1,5 @@
 use rrw::throttle::StupidThrottle;
-use rrw::{RestConfigBuilder, RestRequest};
+use rrw::{Error, RestConfigBuilder, RestRequest, StandardRestError};
 use rrw_macro::rest;
 use serde::{Deserialize, Serialize};
 
@@ -16,7 +16,10 @@ struct Location {
 
 #[rest]
 impl Bahn {
-    async fn location(&self, location: &LocationQuery) -> Result<Vec<Location>, reqwest::Error> {
+    async fn location(
+        &self,
+        location: &LocationQuery,
+    ) -> Result<Vec<Location>, Error<StandardRestError>> {
         RestRequest::<&LocationQuery, ()>::get("/locations").query(location)
     }
 }
